pub struct ClientPool { /* private fields */ }Expand description
The main structure for the HTTP client management pool
Implementations
Sourceimpl ClientPool
impl ClientPool
Sourcepub fn start_monitor_reporter(&self, interval_dur: Duration)
pub fn start_monitor_reporter(&self, interval_dur: Duration)
Periodically prints pool metrics to the console
Sourcepub async fn malloc(&self) -> Option<PooledClientInner>
pub async fn malloc(&self) -> Option<PooledClientInner>
Acquire a client from the pool or create a new one if permitted
Sourcepub fn idle_count(&self) -> usize
pub fn idle_count(&self) -> usize
Returns the number of clients currently available in the pool
Sourcepub fn total_count(&self) -> usize
pub fn total_count(&self) -> usize
Returns the total number of clients managed by this pool
Sourcepub fn working_count(&self) -> usize
pub fn working_count(&self) -> usize
Returns the number of clients currently borrowed and in use